==> Acme-MetaSyntactic-Themes-1.007.tar.gz: Acme-MetaSyntactic-Themes-1.007/lib/Acme/MetaSyntactic/fabeltjeskrant.pm <==
package Acme::MetaSyntactic::fabeltjeskrant;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::fabeltjeskrant - Characters from the 'Fabeltjeskrant'.

=head1 DESCRIPTION

The I<Fabeltjeskrant> was a Dutch puppet animation television series, 
which appeared on and off on Dutch television between 1968 and 1995, 
for a total of 1640 episodes.

Website: L<http://www.fabeltjesweb.nl/>.

=head1 CONTRIBUTOR

Abigail

Introduced in Acme-MetaSyntactic-Themes version 1.004,
published on June 4, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Meneer_de_Uil       Juffrouw_Ooievaar     Lowieke_de_Vos
Meneer_de_Raaf      Bor_de_Wolf           Ed_Bever
Willem_Bever        Zoef_de_Haas          Stoffel_de_Schildpad
Momfer_de_Mol       Truus_de_Mier         Gerrit_de_Postduif
Meindert_het_Paard  Myra_Hamster          Martha_Hamster
Woefdram            Isadora_Paradijsvogel Greta_Bontekoe
Piet_de_Pad
Chico_Lama          Zaza_Zebra            John_Maraboe

Droes_de_Beer       Jodocus_de_Marmot     Teun_Stier
Oleta_Vulpecula     Harry_Lepelaar        Tijl_Schavuit
Sjefke_Schelm       Rocus_de_Vrije_Vogel  Pepijn_de_Kater
Timme_de_Hond       Plons_de_Kikvors      Blinkert_de_Bliek
Arthur_de_Leeuw     Flora_Nachtegaal      George_de_Wezel
Stokebrand_de_Mug   Mia_de_Muilezel       Maup_de_Muis
Marius_de_Bok       Irma_de_Krekel        Orm_de_Aap
Toeter_de_Olifant   Kirreke_de_Tortelduif Koer_de_Tortelduif
Frija_Forel         Greta_2               Hondje_Woef
Wasa_de_Beer        Melis_Das             Lamaar_Snoespoes
Woef_Hektor         Wip_de_Eekhoorn       Gies_de_Vlieg
Arie_de_Rat         Borita                Cas_de_Kraai
Asa_de_Spin

==> Acme-MetaSyntactic-Themes-1.021.tar.gz: Acme-MetaSyntactic-Themes-1.021/lib/Acme/MetaSyntactic/fabeltjeskrant.pm <==
package Acme::MetaSyntactic::fabeltjeskrant;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::fabeltjeskrant - Characters from the 'Fabeltjeskrant'.

=head1 DESCRIPTION

The I<Fabeltjeskrant> was a Dutch puppet animation television series, 
which appeared on and off on Dutch television between 1968 and 1995, 
for a total of 1640 episodes.

Website: L<http://www.fabeltjesweb.nl/>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-06-04 - v1.000

Introduced in Acme-MetaSyntactic-Themes version 1.004.

=item *

2005-10-26

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Meneer_de_Uil       Juffrouw_Ooievaar     Lowieke_de_Vos
Meneer_de_Raaf      Bor_de_Wolf           Ed_Bever
Willem_Bever        Zoef_de_Haas          Stoffel_de_Schildpad
Momfer_de_Mol       Truus_de_Mier         Gerrit_de_Postduif
Meindert_het_Paard  Myra_Hamster          Martha_Hamster
Woefdram            Isadora_Paradijsvogel Greta_Bontekoe
Piet_de_Pad
Chico_Lama          Zaza_Zebra            John_Maraboe

Droes_de_Beer       Jodocus_de_Marmot     Teun_Stier
Oleta_Vulpecula     Harry_Lepelaar        Tijl_Schavuit
Sjefke_Schelm       Rocus_de_Vrije_Vogel  Pepijn_de_Kater
Timme_de_Hond       Plons_de_Kikvors      Blinkert_de_Bliek
Arthur_de_Leeuw     Flora_Nachtegaal      George_de_Wezel
Stokebrand_de_Mug   Mia_de_Muilezel       Maup_de_Muis
Marius_de_Bok       Irma_de_Krekel        Orm_de_Aap
Toeter_de_Olifant   Kirreke_de_Tortelduif Koer_de_Tortelduif
Frija_Forel         Greta_2               Hondje_Woef
Wasa_de_Beer        Melis_Das             Lamaar_Snoespoes
Woef_Hektor         Wip_de_Eekhoorn       Gies_de_Vlieg
Arie_de_Rat         Borita                Cas_de_Kraai
Asa_de_Spin
